@@ -61,7 +61,10 @@ else:
             """
             if self.filename is None or not os.stat(self.filename).st_size:
                 return
-            expro.expro_read(self.filename)
+            try:
+                expro.expro_read(self.filename, 0)
+            except TypeError:
+                expro.expro_read(self.filename)
             self.load_from_expro()
             self.consistent_derived()
             return self
