@@ -307,8 +307,10 @@ def execGlobLoc(obj, userDict, inputDict, persistentDict, runDict, prerun='', po
     GlobLoc['defaultVars'] = defaultVars
 
     # override input
-    def input(*args, **kw):
-        raise Exception('OMFIT scripts do not support input()')
+    def input(prompt=''):
+        from omfit_classes.OMFITx import inputbox
+
+        return inputbox(prompt)
 
     GlobLoc['input'] = input
 
