@@ -872,8 +872,8 @@ If this file is not available to you contact the GA computer group: iris-support
             connection['SERVER'] = rdb_server[2]
             connection['PORT'] = rdb_server[3]
             if 'instance' in MS_server0:
+                connection['SERVER'] = rf"{connection['SERVER']},{connection['PORT']}"
                 del connection['PORT']
-                connection['SERVER'] = rf"{connection['SERVER']}\{MS_server0['instance']}"
             driver = 'tdsodbc'
             if 'driver' in MS_server0:
                 connection['DRIVER'] = driver = evalExpr(MS_server0['driver'])
