@@ -919,13 +919,30 @@ class SortedDict(dict):
     def _keyCaseInsensitive(self, key):
         if not hasattr(self, 'caseInsensitive'):
             self.caseInsensitive = False
-        found = key
-        if self.caseInsensitive and key not in self.keyOrder and isinstance(key, str):
-            for keyL in self.keyOrder:
-                if isinstance(keyL, str) and keyL.lower() == key.lower():
-                    found = keyL
-                    break
-        return found
+
+        if not self.caseInsensitive or not isinstance(key, str):
+            return key
+
+        original_key = key
+        if original_key in self.keyOrder:
+            return original_key
+
+        original_key_lower = key.lower()
+        if original_key_lower in self.keyOrder:
+            return original_key_lower
+
+        original_key_upper = key.upper()
+        if original_key_upper in self.keyOrder:
+            return original_key_upper
+
+        for key in self.keyOrder:
+            try:
+                if key.lower() == original_key_lower:
+                    return key
+            except AttributeError:
+                pass
+
+        return original_key
 
     @_docFromDict
     @dynaLoadKey
