@@ -1297,7 +1297,7 @@ def server_picker(root, MainSettings):
         server_picker_cache[device] = 'iris'
     elif is_localhost('omega'):
         server_picker_cache[device] = 'omega'
-    elif is_localhost(['nx', 'portal', 'sunfire'], looseCheck=True):
+    elif is_localhost(['pppl_sunfire', 'nx', 'portal', 'sunfire'], looseCheck=True):
         server_picker_cache[device] = 'portal'
     else:
         # The decision for server is device dependent
